@@ -48,7 +48,6 @@ public:
 
 
   //Signals:
-#ifndef GLOM_ENABLE_MAEMO
   typedef sigc::signal<void> type_signal_void;
   type_signal_void signal_nav_first();
   type_signal_void signal_nav_prev();
@@ -57,7 +56,6 @@ public:
 
   typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_record_deleted; //arg is PrimaryKey.
   type_signal_record_deleted signal_record_deleted();
-#endif
 
    /** For instance,
     * void on_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
@@ -100,14 +98,12 @@ private:
   //Signal handlers:
   void on_button_new();
 
-#ifndef GLOM_ENABLE_MAEMO
   void on_button_del();
 
   void on_button_nav_first();
   void on_button_nav_prev();
   void on_button_nav_next();
   void on_button_nav_last();
-#endif //GLOM_ENABLE_MAEMO
 
 protected:
 
@@ -142,14 +138,13 @@ protected:
 
   //Member widgets:
   Gtk::ScrolledWindow m_ScrolledWindow;
-  Gtk::HBox m_hbox_content;
+  Gtk::Box m_hbox_content;
   FlowTableWithFields m_FlowTable;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   LayoutToolbar m_Dragbar;
 #endif
 
-#ifndef GLOM_ENABLE_MAEMO
   Gtk::ButtonBox m_hbox_buttons;
   Gtk::Button m_Button_New;
   Gtk::Button m_Button_Del;
@@ -157,12 +152,11 @@ protected:
   Gtk::Button m_Button_Nav_Prev;
   Gtk::Button m_Button_Nav_Next;
   Gtk::Button m_Button_Nav_Last;
-#endif
+
   guint m_ColumnName, m_ColumnValue;
   bool m_bDoNotRefreshRelated; //Stops us from refreshing related records in response to an addition of a related record.
   bool m_ignore_signals;
 
-#ifndef GLOM_ENABLE_MAEMO
   type_signal_void m_signal_nav_first;
   type_signal_void m_signal_nav_prev;
   type_signal_void m_signal_nav_next;
@@ -170,7 +164,6 @@ protected:
 
   type_signal_record_deleted m_signal_record_deleted;
 
-#endif //GLOM_ENABLE_MAEMO
   type_signal_requested_related_details m_signal_requested_related_details;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
