@@ -21,7 +21,7 @@
 #ifndef GLOM_DIALOG_TEXT_FORMATTING_H
 #define GLOM_DIALOG_TEXT_FORMATTING_H
 
-#include <gtkmm/dialog.h>
+#include <gtkmm.h>
 #include <gtkmm/builder.h>
 #include <libglom/document/document.h>
 #include <glom/mode_design/layout/layout_item_dialogs/box_formatting.h>
@@ -29,6 +29,7 @@
 namespace Glom
 {
 
+//TODO: Rename this? It seems to be only used for Print Layouts. Or why not use Dialog_Formatting instead?
 /** A dialog with a titled frame, a label for the table title, and a close button.
  */
 class Dialog_TextFormatting
@@ -42,8 +43,8 @@ public:
   Dialog_TextFormatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_TextFormatting();
 
-  //Allow direct access, for convenience:  
-  Gtk::VBox* m_box_formatting_placeholder;
+  //Allow direct access, for convenience:
+  Gtk::Box* m_box_formatting_placeholder;
   Box_Formatting* m_box_formatting;
 
 private:
