@@ -30,9 +30,7 @@ Box_Data_Details_Find::Box_Data_Details_Find()
 : Box_Data_Details(false)
 {
   //Instead of nav buttons:
-  #ifndef GLOM_ENABLE_MAEMO //TODO_Maemo: Really have this buttons somewhere?
   m_hbox_buttons.pack_end(m_Button_Find, Gtk::PACK_SHRINK);
-  #endif
 
   g_object_set(m_Button_Find.gobj(), "can-default", TRUE, (gpointer)0); //TODO: Make this a real method in gtkmm?
 
