@@ -94,11 +94,8 @@ void CanvasLayoutItem::apply_formatting(const Glib::RefPtr<CanvasTextMovable>& c
   Glib::ustring font = formatting.get_text_format_font();
   if(font.empty())
   {
+    //Just a sanity-check default that should never actually be used:
     font = "Serif 9";
-
-    //Set it in the input parameter,
-    //so that this is the default:
-    //TODO? formatting.set_text_format_font(font);
   }
 
   canvas_item->set_font_points(font);
@@ -190,8 +187,6 @@ int CanvasLayoutItem::get_rows_count_for_portal(const sharedptr<const LayoutItem
 
 Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_item(const sharedptr<LayoutItem>& layout_item)
 {
-  sharedptr<LayoutItem_Line> line;
-
   Glib::RefPtr<CanvasItemMovable> child;
   Glib::RefPtr<Goocanvas::Item> child_item;
   sharedptr<LayoutItem_Text> text = sharedptr<LayoutItem_Text>::cast_dynamic(layout_item);
@@ -218,7 +213,8 @@ Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_
       else
         canvas_item->set_image_empty(); //show a no-image picture.
 
-      canvas_item->property_fill_color() = "white"; //This makes the whole area clickable, not just the outline stroke.
+      //canvas_item->property_fill_color() = "white"; //This makes the whole area clickable, not just the outline stroke.
+      //canvas_item->property_fill_color_rgba() = 0xFFFFFF00;
 
       child = canvas_item;
       child_item = canvas_item;
@@ -235,8 +231,8 @@ Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_
         line->get_coordinates(start_x, start_y, end_x, end_y);
 
         Glib::RefPtr<CanvasLineMovable> canvas_item = CanvasLineMovable::create();
-        canvas_item->property_line_width() = 1;
-        canvas_item->property_stroke_color() = "black";
+        canvas_item->property_line_width() = line->get_line_width();
+        canvas_item->property_stroke_color() = line->get_line_color();
 
         Goocanvas::Points points(2);
         points.set_coordinate(0, start_x, start_y);
@@ -281,19 +277,24 @@ Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_
           if(portal)
           {
             Glib::RefPtr<CanvasTableMovable> canvas_item = CanvasTableMovable::create();
-            canvas_item->property_vert_grid_line_width() = 1;
-            canvas_item->property_horz_grid_line_width() = 1;
-            canvas_item->property_stroke_color() = "black";
+
+            canvas_item->set_lines_details(
+              portal->get_print_layout_row_line_width(),
+              portal->get_print_layout_column_line_width(),
+              portal->get_print_layout_line_color());
 
             //Show as many rows as can fit in the height.
             double row_height = 0;
             const int max_rows = get_rows_count_for_portal(portal, row_height);
+            std::cout << "DEBUG: max_rows=" << max_rows << ", row_height=" << row_height << std::endl;
 
             const LayoutGroup::type_list_items child_items = portal->get_items();
 
             for(guint row = 0; row < (guint)max_rows; ++row)
             {
               guint col = 0;
+              const guint num_cols = child_items.size();
+              bool something_expanded = false;
               for(LayoutGroup::type_list_items::const_iterator iter = child_items.begin(); iter != child_items.end(); ++iter)
               {
                 sharedptr<LayoutItem> layout_item = *iter;
@@ -303,22 +304,56 @@ Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_
                 //but goocanvas cannot yet support Groups inside Tables. murrayc.
                 //TODO: Bug number.
                 Glib::RefPtr<CanvasItemMovable> cell = create_canvas_item_for_layout_item(layout_item);
-                if(cell)
-                {
-                  //Make sure that the width is sensible:
-                  guint width = layout_item->get_display_width();
-                  width = std::max(width, (guint)10);
-                  cell->set_width_height(width, row_height);
-                  std::cout << "DEBUG: width=" << width << std::endl;
+                Glib::RefPtr<Goocanvas::Item> cell_as_item = CanvasItemMovable::cast_to_item(cell);
 
-                  //TODO: Add/Remove rows when resizing, instead of resizing the rows:
-                  Glib::RefPtr<Goocanvas::Item> cell_as_item = CanvasItemMovable::cast_to_item(cell);
-                  if(cell_as_item)
+                if(cell && cell_as_item)
+                {
+                  const guint width = layout_item->get_display_width();
+                  bool expand = (width == 0);
+                  
+                  //If this is the last item, and no other item has expanded,
+                  //let this one expand,
+                  //Otherwise, we could allocate less space than the table has left.
+                  //TODO: Prevent the user from allocating _more_ space than the table has.
+                  if(!something_expanded && (col == (num_cols - 1)))
                   {
+                    expand = true;
+                  }
+                  
+                  if(expand)
+                  {
+                    //Let the table allocate the width automatically:
+                    
+                    cell->set_width_height(-1, row_height);
                     canvas_item->attach(cell_as_item,
-                      col /* left_attach */, col+1 /* right_attach */,
+                      col /* left_attach */, col + 1 /* right_attach */,
                       row /* top_attach */, row + 1 /* right_attach */,
-                      Gtk::FILL, (Gtk::AttachOptions)Gtk::FILL | Gtk::EXPAND);
+                      (Gtk::AttachOptions)(Gtk::FILL | Gtk::EXPAND), (Gtk::AttachOptions)(Gtk::FILL | Gtk::EXPAND));
+                      
+                    something_expanded = true;
+                  }
+                  else
+                  {
+                    //Enforce a width:
+                    
+                    //TODO: Add/Remove rows when resizing, instead of resizing the rows:
+                    cell->set_width_height(width, row_height);
+
+                    canvas_item->attach(cell_as_item,
+                      col /* left_attach */, col + 1 /* right_attach */,
+                      row /* top_attach */, row + 1 /* right_attach */,
+                      (Gtk::FILL), (Gtk::AttachOptions)(Gtk::FILL | Gtk::EXPAND));
+                      
+                    //Add a second item (an invisible rect) to make sure that the size is really used:
+                    Glib::RefPtr<Goocanvas::Rect> rect = 
+                      Goocanvas::Rect::create(0, 0, width, row_height);
+                    //TODO: Find out why this doesn't work: rect->property_stroke_pattern() = Cairo::RefPtr<Cairo::Pattern>();
+                    g_object_set(rect->gobj(), "stroke-pattern", (void*)0, (void*)0);
+                     
+                    canvas_item->attach(rect,
+                      col /* left_attach */, col + 1 /* right_attach */,
+                      row /* top_attach */, row + 1 /* right_attach */,
+                      Gtk::SHRINK, Gtk::SHRINK);
                   }
                 }
 
@@ -343,33 +378,6 @@ Glib::RefPtr<CanvasItemMovable> CanvasLayoutItem::create_canvas_item_for_layout_
   }
 
   return child;
-
-  if(child && child_item)
-  {
-    //child_item->property_pointer_events() =
-    //  (Goocanvas::PointerEvents)(Goocanvas::EVENTS_VISIBLE_FILL & GOO_CANVAS_EVENTS_VISIBLE_STROKE);
-
-    //Set the position and dimensions of this group to match the child:
-    double x = 0;
-    double y = 0;
-    double width = 0;
-    double height = 0;
-    layout_item->get_print_layout_position(x, y, width, height);
-    child->set_width_height(width, height);
-    //std::cout << "debug: " << G_STRFUNC << ": item x=" << x << std::endl;
-  }
-
-  //Scale images.
-  //This can only be done after setting the size:
-  Glib::RefPtr<CanvasImageMovable> canvas_image = Glib::RefPtr<CanvasImageMovable>::cast_dynamic(child);
-  if(canvas_image)
-  {
-    canvas_image->scale_to_size();
-
-    //It will also be rescaled when this canvas item is resized - see on_resized().
-  }
-
-  return child;
 }
 
 void CanvasLayoutItem::set_db_data(const Gnome::Gda::Value& value)
@@ -447,4 +455,23 @@ void CanvasLayoutItem::remove_empty_indicators()
   }
 }
 
+void CanvasLayoutItem::update_layout_position_from_canvas()
+{
+  sharedptr<LayoutItem> layout_item = get_layout_item();
+  if(!layout_item)
+    return;
+
+  //Get the actual position:
+  double x = 0;
+  double y = 0;
+  get_xy(x, y);
+  //std::cout << "debug: " << G_STRFUNC << ": x=" << x << std::endl;
+
+  double width = 0;
+  double height = 0;
+  get_width_height(width, height);
+
+  layout_item->set_print_layout_position(x, y, width, height);
+}
+
 } //namespace Glom
