@@ -24,11 +24,13 @@
 #include <gtkmm/stock.h>
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
 #include <glom/mode_design/layout/dialog_layout_list_related.h>
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_line.h>
 
 //TODO: Remove these when we can just use a CanvasLayoutItem in a GooCanvasTable:
 #include <glom/utility_widgets/canvas/canvas_table_movable.h>
 #include <glom/utility_widgets/canvas/canvas_image_movable.h>
 #include <glom/utility_widgets/canvas/canvas_text_movable.h>
+#include <glom/application.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
 
@@ -38,16 +40,10 @@
 namespace Glom
 {
 
-/*
-static bool on_group_button_press_event(const Glib::RefPtr<Goocanvas::Item>& target, GdkEventButton* event)
-{
-  return true; // Let the child items get the event.
-}
-*/
-
 Canvas_PrintLayout::Canvas_PrintLayout()
 : m_modified(false),
-  m_dialog_format(0)
+  m_dialog_format(0),
+  m_outline_visibility(false)
 {
   #ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_context_menu();
@@ -81,6 +77,7 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
   remove_all_items(m_items_group);
   add_layout_group(print_layout->m_layout_group, true /* is top-level */);
 
+  //Use the page setup:
   Glib::RefPtr<Gtk::PageSetup> page_setup;
   const Glib::ustring key_file_text = print_layout->get_page_setup();
   if(!key_file_text.empty())
@@ -90,12 +87,33 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
     //TODO: Catch an exception
     key_file.load_from_data(key_file_text);
 
-    //TODO: Use this when gtkmm and GTK+ have been fixed: page_setup = Gtk::PageSetup::create(key_file);
-    page_setup = Glib::wrap(gtk_page_setup_new_from_key_file(key_file.gobj(), 0, 0));
+    page_setup = Gtk::PageSetup::create_from_key_file(key_file);
   }
 
   set_page_setup(page_setup);
 
+
+  //Add the rule lines:
+  remove_rules();
+
+  const PrintLayout::type_vec_doubles h_rules = print_layout->get_horizontal_rules();
+  for(PrintLayout::type_vec_doubles::const_iterator iter = h_rules.begin();
+    iter != h_rules.end(); ++iter)
+  {
+    add_horizontal_rule(*iter);
+  }
+
+  const PrintLayout::type_vec_doubles v_rules = print_layout->get_vertical_rules();
+  for(PrintLayout::type_vec_doubles::const_iterator iter = v_rules.begin();
+    iter != v_rules.end(); ++iter)
+  {
+    add_vertical_rule(*iter);
+  }
+
+  //TODO: This needs a number, but that is decided in WindowPrintLayoutEdit: set_grid_gap( print_layout->get_show_grid() );
+  set_rules_visibility( print_layout->get_show_rules() );
+  set_outlines_visibility( print_layout->get_show_outlines() );
+
   m_modified = false;
 }
 
@@ -115,6 +133,9 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 
   result->set_page_setup(data);
 
+  result->set_horizontal_rules( get_horizontal_rules() );
+  result->set_vertical_rules( get_horizontal_rules() );
+
   return result;
 }
 
@@ -153,7 +174,7 @@ void Canvas_PrintLayout::add_layout_group_children(const sharedptr<LayoutGroup>&
   m_modified = true;
 }
 
-void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutItem> item)
+void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutItem>& item)
 {
   if(!item)
     return;
@@ -170,6 +191,15 @@ void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutI
       item) );
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
+   item->set_outline_visible(m_outline_visibility);
+}
+
+void Canvas_PrintLayout::remove_canvas_layout_item(const Glib::RefPtr<CanvasLayoutItem>& item)
+{
+  if(!item)
+    return;
+
+  CanvasEditable::remove_item(item, m_items_group);
 }
 
 void Canvas_PrintLayout::add_layout_group(const sharedptr<LayoutGroup>& group, bool is_top_level)
@@ -211,11 +241,9 @@ void Canvas_PrintLayout::fill_layout_group(const sharedptr<LayoutGroup>& group)
       if((width != 0)) //Allow height to be 0, because text items currently have no height. TODO: && (height != 0)) //Avoid bogus items.
       {
       */
-        sharedptr<LayoutItem> layout_item = canvas_item->get_layout_item();
-        //std::cout << "DEBUG: saving layout_item type=" << layout_item->get_part_type_name() << std::endl;
-        update_layout_position_from_canvas(layout_item, canvas_item);
+        canvas_item->update_layout_position_from_canvas();
 
-        group->add_item(layout_item);
+        group->add_item(canvas_item->get_layout_item());
       //}
     }
 
@@ -235,7 +263,7 @@ void Canvas_PrintLayout::setup_context_menu()
   m_context_menu_action_group->add(action,
     sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_insert_field) );
 
-  action =  Gtk::Action::create("ContextInsertText", _("Text"));
+  action = Gtk::Action::create("ContextInsertText", _("Text"));
   m_context_menu_action_group->add(action,
     sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_insert_text) );
 */
@@ -280,14 +308,31 @@ void Canvas_PrintLayout::setup_context_menu()
 
 void Canvas_PrintLayout::on_item_show_context_menu(guint button, guint32 activate_time, Glib::RefPtr<CanvasLayoutItem> item)
 {
-  if(!m_context_menu)
+  if(!m_context_menu || !item)
     return;
 
   m_context_item = item;
+  
+  //Do not enable the Formatting menu item for all types of items:
+  sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
+  bool enable_formatting = false;
+  if(sharedptr<LayoutItem_WithFormatting>::cast_dynamic(layout_item))
+  {
+    enable_formatting = true;
+  }
+
+  m_action_formatting->set_sensitive(enable_formatting);
 
   m_context_menu->popup(button, activate_time);
 }
 
+bool Canvas_PrintLayout::on_background_button_press_event(const Glib::RefPtr<Goocanvas::Item>& /* target */, GdkEventButton* /* event */)
+{
+  //A click on empty space should deselect any selected items:
+  select_all(false);
+  return false;
+}
+
 sharedptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const sharedptr<LayoutItem_Portal>& portal, Gtk::Window* parent)
 {
   sharedptr<LayoutItem_Portal> result = portal;
@@ -299,7 +344,9 @@ sharedptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const sha
 
   add_view(dialog); //Give it access to the document.
 
-  dialog->set_document("layout_name_unused_for_portals", "", /* layout_platform */ get_document(), portal, m_table_name);
+  dialog->set_document("layout_name_unused_for_portals", "", /* layout_platform */
+    get_document(), portal, m_table_name,
+    true /* for print layout */);
 
   if(parent)
     dialog->set_transient_for(*parent);
@@ -314,19 +361,52 @@ sharedptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const sha
   return result;
 }
 
+sharedptr<LayoutItem_Line> Canvas_PrintLayout::offer_line(const sharedptr<LayoutItem_Line>& line, Gtk::Window* parent)
+{
+  sharedptr<LayoutItem_Line> result = line;
+
+  Dialog_Line* dialog = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
+
+  if(parent)
+    dialog->set_transient_for(*parent);
+    
+  dialog->set_line(line);
+
+  const int response = Glom::Utils::dialog_run_with_help(dialog);
+  dialog->hide();
+  if(response == Gtk::RESPONSE_OK)
+  {
+    //Get the chosen relationship:
+    result = dialog->get_line();
+  }
+
+  delete dialog;
+
+  return result;
+}
+
 void Canvas_PrintLayout::on_context_menu_edit()
 {
   Gtk::Window* parent = dynamic_cast<Gtk::Window*>(get_toplevel());
 
-  sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
-  update_layout_position_from_canvas(layout_item, m_context_item);
+  m_context_item->update_layout_position_from_canvas();
 
-  sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+  sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
+  sharedptr<LayoutItem_Field> field = 
+    sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
   if(field)
   {
     sharedptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_table_name, parent);
     if(field_chosen)
+    {
+      //Never use the default formatting for print layouts:
+      field_chosen->set_formatting_use_default(false);
+
       m_context_item->set_layout_item(field_chosen);
+    }
   }
   else
   {
@@ -352,6 +432,15 @@ void Canvas_PrintLayout::on_context_menu_edit()
           portal = offer_related_records(portal, parent);
           m_context_item->set_layout_item(portal);
         }
+        else
+        {
+         sharedptr<LayoutItem_Line> line = sharedptr<LayoutItem_Line>::cast_dynamic(layout_item);
+         if(line)
+         {
+           line = offer_line(line, parent);
+           m_context_item->set_layout_item(line);
+         }
+        }
       }
     }
   }
@@ -366,9 +455,9 @@ void Canvas_PrintLayout::on_context_menu_formatting()
   if(!m_context_item)
     return;
 
-  sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
-  update_layout_position_from_canvas(layout_item, m_context_item);
+  m_context_item->update_layout_position_from_canvas();
 
+  sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
   sharedptr<LayoutItem_Field> layout_item_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
   sharedptr<LayoutItem_Text> layout_item_text = sharedptr<LayoutItem_Text>::cast_dynamic(layout_item);
   if(!layout_item_field && !layout_item_text)
@@ -384,6 +473,10 @@ void Canvas_PrintLayout::on_context_menu_formatting()
   Utils::get_glade_widget_derived_with_warning(m_dialog_format);
   add_view(m_dialog_format);
 
+  Gtk::Window* window = dynamic_cast<Gtk::Window*>(get_toplevel());
+  if(window)
+    m_dialog_format->set_transient_for(*window);
+
   m_dialog_format->signal_hide().connect( sigc::mem_fun(*this, &Canvas_PrintLayout::on_dialog_format_hide) );
 
   //We need an if here, because they have no common base class.
@@ -396,7 +489,8 @@ void Canvas_PrintLayout::on_context_menu_formatting()
   else
   {
     const FieldFormatting& formatting = layout_item_text->m_formatting;
-    m_dialog_format->m_box_formatting->set_formatting_for_non_field(formatting);
+    m_dialog_format->m_box_formatting->set_formatting_for_non_field(
+      formatting, false /* don't show numeric options */);
   }
 
   m_dialog_format->m_box_formatting->set_is_for_non_editable();
@@ -406,8 +500,32 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 
 void Canvas_PrintLayout::on_context_menu_delete()
 {
-  m_context_item->remove();
+  //If the item to be deleted was not selected then just delete it:
+  if(!m_context_item->get_selected())
+  {
+    m_context_item->remove();
+    m_context_item.reset();
+    return;
+  }
+
+  //Requesting deletion of a selected item should delete all selected items:
+  //TODO: If there are multiple items, ask the user for confirmation?
   m_context_item.reset();
+  const type_vec_items items = get_selected_items();
+  for(type_vec_items::const_iterator iter = items.begin();
+    iter != items.end(); ++iter)
+  {
+    const Glib::RefPtr<CanvasItemMovable> selected_item = *iter;
+    if(!selected_item)
+      continue;
+      
+    const Glib::RefPtr<CanvasLayoutItem> canvas_layout_item = 
+      Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(selected_item);
+    if(canvas_layout_item)
+      remove_canvas_layout_item(canvas_layout_item);
+  }
+  
+  signal_selection_changed().emit();
 }
 
 void Canvas_PrintLayout::on_dialog_format_hide()
@@ -422,10 +540,16 @@ void Canvas_PrintLayout::on_dialog_format_hide()
     return;
 
   if(layout_item_field)
+  {
     m_dialog_format->m_box_formatting->get_formatting(layout_item_field->m_formatting);
+
+    //Never use the default formatting for print layouts:
+    layout_item_field->set_formatting_use_default(false);
+  }
   else if(layout_item_text)
     m_dialog_format->m_box_formatting->get_formatting(layout_item_text->m_formatting);
 
+  
   m_context_item->set_layout_item(layout_item); //Redraw the child item with the new formatting.
 
   delete m_dialog_format;
@@ -434,24 +558,6 @@ void Canvas_PrintLayout::on_dialog_format_hide()
 
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
-
-void Canvas_PrintLayout::update_layout_position_from_canvas(const sharedptr<LayoutItem> layout_item, const Glib::RefPtr<const CanvasLayoutItem>& canvas_item)
-{
-  if(!layout_item || !canvas_item)
-    return;
-
-  //Get the actual position:
-  double x = 0;
-  double y = 0;
-  canvas_item->get_xy(x, y);
-  //std::cout << "debug: " << G_STRFUNC << ": x=" << x << std::endl;
-
-  double width = 0;
-  double height = 0;
-  canvas_item->get_width_height(width, height);
-  layout_item->set_print_layout_position(x, y, width, height);
-}
-
 Glib::RefPtr<Goocanvas::Polyline> Canvas_PrintLayout::create_margin_line(double x1, double y1, double x2, double y2)
 {
   Glib::RefPtr<Goocanvas::Polyline> line =
@@ -459,6 +565,11 @@ Glib::RefPtr<Goocanvas::Polyline> Canvas_PrintLayout::create_margin_line(double
   line->property_line_width() = 0.5;
   line->property_stroke_color() = "light gray";
 
+  //Interpret a click on the line like a click on the background behind it:
+  //TODO: Do this for grid lines and rules too:
+  line->signal_button_press_event().connect(
+    sigc::mem_fun(*this, &Canvas_PrintLayout::on_background_button_press_event));
+
   m_bounds_group->add_child(line);
   return line;
 }
@@ -470,7 +581,7 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
     return;
 
   //Change the scroll extents to match the page size:
-  Gtk::PaperSize paper_size = m_page_setup->get_paper_size();
+  const Gtk::PaperSize paper_size = m_page_setup->get_paper_size();
   Goocanvas::Bounds bounds;
   bounds.set_x1(0);
   bounds.set_y1(0);
@@ -510,6 +621,8 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
   m_bounds_rect = Goocanvas::Rect::create(bounds.get_x1(), bounds.get_y1(), bounds.get_x2(), bounds.get_y2());
   m_bounds_rect->property_fill_color() = "white";
   m_bounds_rect->property_line_width() = 0;
+  m_bounds_rect->signal_button_press_event().connect(
+    sigc::mem_fun(*this, &Canvas_PrintLayout::on_background_button_press_event));
   m_bounds_group->add_child(m_bounds_rect);
 
   //Make sure that the bounds rect is at the bottom,
@@ -523,6 +636,15 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
   m_margin_bottom = create_margin_line(bounds.get_x1(), bounds.get_y2() - page_setup->get_bottom_margin(units), bounds.get_x2(), bounds.get_y2() - page_setup->get_bottom_margin(units));
 
   m_bounds_group->lower();
+
+  //Try to show the whole thing, by (indirectly) making the parent window big enough:
+  /* TODO: This doesn't seem to work
+  double width_pixels = bounds.get_x2() - bounds.get_x1();
+  double height_pixels = bounds.get_y2() - bounds.get_y1();
+  convert_to_pixels(width_pixels, height_pixels);
+  std::cout << "DEBUG: width_pixels=" << width_pixels << ", height_pixels=" << height_pixels << std::endl;
+  set_size_request(width_pixels, height_pixels);
+  */
 }
 
 Glib::RefPtr<Gtk::PageSetup> Canvas_PrintLayout::get_page_setup()
@@ -870,4 +992,74 @@ Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show
 }
 
 
+Canvas_PrintLayout::type_vec_items Canvas_PrintLayout::get_selected_items()
+{
+  type_vec_items result;
+
+  //TODO: Do this recursively.
+  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  if(!root)
+    return result;
+
+  const int count = root->get_n_children();
+  for(int i = 0; i < count; ++i)
+  {
+    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
+    Glib::RefPtr<CanvasLayoutItem> derived =
+      Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
+    if(!derived)
+      continue;
+
+    if(derived->get_selected())
+      result.push_back(derived);
+  }
+
+  return result;
+}
+
+void Canvas_PrintLayout::set_outlines_visibility(bool visible)
+{
+  //Remember this so we can apply it to items added later:
+  m_outline_visibility = visible;
+
+  //TODO: Do this recursively.
+  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  if(!root)
+    return;
+
+  const int count = root->get_n_children();
+  for(int i = 0; i < count; ++i)
+  {
+    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
+    Glib::RefPtr<CanvasLayoutItem> derived =
+      Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
+    if(!derived)
+      continue;
+
+    derived->set_outline_visible(visible);
+  }
+}
+
+void Canvas_PrintLayout::select_all(bool selected)
+{
+  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  if(!root)
+    return;
+
+  const int count = root->get_n_children();
+  for(int i = 0; i < count; ++i)
+  {
+    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
+    Glib::RefPtr<CanvasLayoutItem> derived =
+      Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
+    if(!derived)
+      continue;
+
+    derived->set_selected(selected);
+  }
+
+  signal_selection_changed().emit();
+}
+
+
 } //namespace Glom
