@@ -21,6 +21,7 @@
 #include "canvas_group_resizable.h"
 #include "canvas_rect_movable.h"
 #include "canvas_line_movable.h"
+#include <glom/utility_widgets/canvas/canvas_table_movable.h>
 #include <goocanvasmm/canvas.h>
 #include <goocanvasrect.h>
 #include <goocanvasgroup.h>
@@ -29,10 +30,18 @@
 namespace Glom
 {
 
-static const double manipulator_corner_size = 2;
-static const gchar* manipulator_corner_fill_color = "black";
-static const double manipulator_stroke_width = 1.0; //mm (assuming that the canvas uses mm.
-static const gchar* manipulator_stroke_color = "black";
+static const double MANIPULATOR_CORNER_SIZE = 2;
+static const char MANIPULATOR_CORNER_FILL_COLOR[] = "black";
+static const double MANIPULATOR_STROKE_WIDTH = 0.5f; //mm (assuming that the canvas uses mm.
+static const char MANIPULATOR_STROKE_COLOR[] = "black";
+static const double OUTLINE_STROKE_WIDTH = MANIPULATOR_STROKE_WIDTH; //mm (assuming that the canvas uses mm.
+static const char OUTLINE_STROKE_COLOR[] = "gray";
+
+void CanvasGroupResizable::get_outline_stroke(Glib::ustring& color, double& width)
+{
+  color = OUTLINE_STROKE_COLOR;
+  width = OUTLINE_STROKE_WIDTH;
+}
 
 CanvasGroupResizable::CanvasGroupResizable()
 : m_in_manipulator(false),
@@ -48,11 +57,17 @@ CanvasGroupResizable::CanvasGroupResizable()
 void CanvasGroupResizable::create_manipulators()
 {
   //Remove any existing manipulators:
-  if(m_group_manipulators)
-    m_group_manipulators->remove();
+  if(m_group_edge_manipulators)
+    m_group_edge_manipulators->remove();
+
+  if(m_group_corner_manipulators)
+    m_group_corner_manipulators->remove();
   
-  m_group_manipulators = Goocanvas::Group::create();
-  add_child(m_group_manipulators);
+  m_group_edge_manipulators = Goocanvas::Group::create();
+  add_child(m_group_edge_manipulators);
+
+  m_group_corner_manipulators = Goocanvas::Group::create();
+  add_child(m_group_corner_manipulators);
 
   if(get_is_line())
     create_line_manipulators();
@@ -63,13 +78,8 @@ void CanvasGroupResizable::create_manipulators()
 void CanvasGroupResizable::create_rect_manipulators()
 {
   m_rect = Goocanvas::Rect::create(0, 0, 0, 0);
-#ifdef GLIBMM_PROPERTIES_ENABLED  
   m_rect->property_line_width() = 0;
-  m_rect->property_fill_color() = "white";
-#else
-  m_rect->set_property("line-width", 0);
-  m_rect->set_property("fill-color", Glib::ustring("white"));
-#endif  
+  m_rect->property_fill_color_rgba() = 0xFFFFFF00; //Needed to make it react to drags. White but completely transparent.
   add_child(m_rect);
 
   //Allow dragging of the rect to move everything:
@@ -94,14 +104,14 @@ void CanvasGroupResizable::create_rect_manipulators()
   m_manipulator_edge_left = create_edge_manipulator();
   m_manipulator_edge_right = create_edge_manipulator();
 
-  m_group_manipulators->add_child(m_manipulator_corner_top_left);
-  m_group_manipulators->add_child(m_manipulator_corner_top_right);
-  m_group_manipulators->add_child(m_manipulator_corner_bottom_left);
-  m_group_manipulators->add_child(m_manipulator_corner_bottom_right);
-  m_group_manipulators->add_child(m_manipulator_edge_top);
-  m_group_manipulators->add_child(m_manipulator_edge_bottom);
-  m_group_manipulators->add_child(m_manipulator_edge_left);
-  m_group_manipulators->add_child(m_manipulator_edge_right);
+  m_group_corner_manipulators->add_child(m_manipulator_corner_top_left);
+  m_group_corner_manipulators->add_child(m_manipulator_corner_top_right);
+  m_group_corner_manipulators->add_child(m_manipulator_corner_bottom_left);
+  m_group_corner_manipulators->add_child(m_manipulator_corner_bottom_right);
+  m_group_edge_manipulators->add_child(m_manipulator_edge_top);
+  m_group_edge_manipulators->add_child(m_manipulator_edge_bottom);
+  m_group_edge_manipulators->add_child(m_manipulator_edge_left);
+  m_group_edge_manipulators->add_child(m_manipulator_edge_right);
 
   m_manipulator_corner_top_left->set_grid(m_grid);
   m_manipulator_corner_top_left->set_snap_corner(CanvasRectMovable::CORNER_TOP_LEFT);
@@ -125,6 +135,10 @@ void CanvasGroupResizable::create_rect_manipulators()
   m_manipulator_edge_left->set_drag_cursor(Gdk::LEFT_SIDE);
   m_manipulator_edge_right->set_drag_cursor(Gdk::RIGHT_SIDE);
 
+  //Make sure that this is above the outline group:
+  m_group_edge_manipulators->raise();//m_group_outline);
+  m_group_corner_manipulators->raise();//m_group_outline);
+
   manipulator_connect_signals(m_manipulator_corner_top_left, MANIPULATOR_CORNER_TOP_LEFT);
   manipulator_connect_signals(m_manipulator_corner_top_right, MANIPULATOR_CORNER_TOP_RIGHT);
   manipulator_connect_signals(m_manipulator_corner_bottom_left, MANIPULATOR_CORNER_BOTTOM_LEFT);
@@ -139,8 +153,11 @@ void CanvasGroupResizable::create_line_manipulators()
 {
   m_manipulator_start = create_corner_manipulator();
   m_manipulator_end = create_corner_manipulator();
-  m_group_manipulators->add_child(m_manipulator_start);
-  m_group_manipulators->add_child(m_manipulator_end);
+
+  //We add these to the edge manipulators, though they look like 
+  //corner manipulators, because we want to use them to show selection.
+  m_group_edge_manipulators->add_child(m_manipulator_start);
+  m_group_edge_manipulators->add_child(m_manipulator_end);
 
   m_manipulator_start->set_grid(m_grid);
   //m_manipulator_corner_top_left->set_snap_corner(CanvasRectMovable::CORNER_TOP_LEFT);
@@ -154,6 +171,48 @@ void CanvasGroupResizable::create_line_manipulators()
   manipulator_connect_signals(m_manipulator_end, MANIPULATOR_END);
 }
 
+Glib::RefPtr<CanvasLineMovable> CanvasGroupResizable::create_outline_line(double x1, double y1, double x2, double y2)
+{
+  Glib::RefPtr<CanvasLineMovable> line = Glom::CanvasLineMovable::create();
+  line->property_line_width() = OUTLINE_STROKE_WIDTH;
+  line->property_stroke_color() = OUTLINE_STROKE_COLOR;
+  line->set_movement_allowed(false, false);
+  m_group_outline->add_child(line);
+  set_edge_points(line, x1, y1, x2, y2);
+  return line;
+}
+
+void CanvasGroupResizable::create_outline_group()
+{
+  //Add something to indicate when the item is selected:
+  if(m_group_outline)
+    m_group_outline->remove();
+  m_group_outline = Goocanvas::Group::create();
+  add_child(m_group_outline);
+
+  double x1 = 0;
+  double y1 = 0;
+  get_xy(x1, y1);
+
+  double child_width = 0;
+  double child_height = 0;
+  get_width_height(child_width, child_height);
+
+  const double x2 = x1 + child_width;
+  const double y2 = y1 + child_height;
+
+  m_outline_top = create_outline_line(x1, y1, x2, y1);
+  m_outline_bottom = create_outline_line(x1, y2, x2, y2);
+  m_outline_left = create_outline_line(x1, y1, x1, y2);
+  m_outline_right = create_outline_line(x2, y1, x2, y2);
+}
+
+void CanvasGroupResizable::set_outline_visible(bool visible)
+{
+  m_group_outline->property_visibility() = 
+    (visible ? Goocanvas::ITEM_VISIBLE : Goocanvas::ITEM_INVISIBLE);
+}
+
 CanvasGroupResizable::~CanvasGroupResizable()
 {
 }
@@ -163,6 +222,12 @@ Glib::RefPtr<CanvasGroupResizable> CanvasGroupResizable::create()
   return Glib::RefPtr<CanvasGroupResizable>(new CanvasGroupResizable());
 }
 
+void CanvasGroupResizable::position_extras()
+{
+  position_manipulators();
+  position_outline();
+}
+
 void CanvasGroupResizable::position_manipulators()
 {
   if(get_is_line())
@@ -186,29 +251,21 @@ void CanvasGroupResizable::position_rect_manipulators()
 
   double child_x = 0;
   double child_y = 0;
-  get_xy(child_x, child_y);
-  //std::cout << "  CanvasGroupResizable::position_manipulators(): child x=" << child_x << std::endl;
+  get_xy(child_x, child_y); //TODO: Remove duplicate get_xy() call?
+  //std::cout << "debug: " << G_STRFUNC << ": child x=" << child_x << std::endl;
 
   double child_width = 0;
   double child_height = 0;
   get_width_height(child_width, child_height);
-  //std::cout << "  CanvasGroupResizable::position_manipulators(): child width=" << child_width << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": child width=" << child_width << std::endl;
 
 
   //Show the size of this item (not always the same as the child size):
-#ifdef GLIBMM_PROPERTIES_ENABLED  
   m_rect->property_x() = child_x;
   m_rect->property_y() = child_y;
   m_rect->property_width() = child_width;
   m_rect->property_height() = child_height;
-  m_rect->property_fill_color() = "white";
-#else
-  m_rect->set_property("x", child_x);
-  m_rect->set_property("y", child_y);
-  m_rect->set_property("width", child_width);
-  m_rect->set_property("height",child_height);
-  m_rect->set_property("fill_color", Glib::ustring("white"));
-#endif
+  //m_rect->property_fill_color_rgba() = 0xFFFFFF00;
 
   const double x2 = child_x + child_width;
   const double y2 = child_y + child_height;
@@ -216,9 +273,9 @@ void CanvasGroupResizable::position_rect_manipulators()
   Glib::RefPtr<Goocanvas::Item> item = CanvasItemMovable::cast_to_item(m_child);
 
   m_manipulator_corner_top_left->set_xy(x1, y1);
-  m_manipulator_corner_top_right->set_xy(x2 - manipulator_corner_size, y1);
-  m_manipulator_corner_bottom_left->set_xy(x1, y2 - manipulator_corner_size);
-  m_manipulator_corner_bottom_right->set_xy(x2 - manipulator_corner_size, y2 - manipulator_corner_size);
+  m_manipulator_corner_top_right->set_xy(x2 - MANIPULATOR_CORNER_SIZE, y1);
+  m_manipulator_corner_bottom_left->set_xy(x1, y2 - MANIPULATOR_CORNER_SIZE);
+  m_manipulator_corner_bottom_right->set_xy(x2 - MANIPULATOR_CORNER_SIZE, y2 - MANIPULATOR_CORNER_SIZE);
   set_edge_points(m_manipulator_edge_top, x1, y1, x2, y1);
   set_edge_points(m_manipulator_edge_bottom, x1, y2, x2, y2);
   set_edge_points(m_manipulator_edge_left, x1, y1, x1, y2);
@@ -228,12 +285,14 @@ void CanvasGroupResizable::position_rect_manipulators()
   //and the manipulators are above the item (and above the rect):
   if(item)
   {
-    m_group_manipulators->raise(item);
+    m_group_edge_manipulators->raise();
+    m_group_corner_manipulators->raise();
     m_rect->lower(item);
   }
   else
   {
-    m_group_manipulators->raise(m_rect);
+    m_group_edge_manipulators->raise();
+    m_group_corner_manipulators->raise();
   }
 }
 
@@ -243,12 +302,7 @@ void CanvasGroupResizable::position_line_manipulators()
   if(!line)
     return;
 
-#ifdef GLIBMM_PROPERTIES_ENABLED
   const Goocanvas::Points points = line->property_points();
-#else
-  Goocanvas::Points points;
-  line->get_property("points", points);
-#endif
   if(points.get_num_points() < 2)
     return;
 
@@ -256,7 +310,7 @@ void CanvasGroupResizable::position_line_manipulators()
   double start_y = 0;
   points.get_coordinate(0, start_x, start_y);
 
-  const double half_size = manipulator_corner_size / 2;
+  const double half_size = MANIPULATOR_CORNER_SIZE / 2;
   m_manipulator_start->set_xy(start_x - half_size, start_y - half_size); //Center it over the point.
 
   double end_x = 0;
@@ -265,7 +319,53 @@ void CanvasGroupResizable::position_line_manipulators()
 
   m_manipulator_end->set_xy(end_x - half_size, end_y - half_size); //Center it over the point.
 
-  m_group_manipulators->raise(line);
+  m_group_edge_manipulators->raise();
+  m_group_corner_manipulators->raise();
+}
+
+void CanvasGroupResizable::position_outline()
+{
+  if(!m_rect)
+    return;
+
+  //Note that this only works after the child has been added to the canvas:
+  //Goocanvas::Bounds bounds;
+  //m_child->get_bounds(bounds);
+ 
+  double x1 = 0;
+  double y1 = 0;
+  get_xy(x1, y1);
+
+  double child_width = 0;
+  double child_height = 0;
+  get_width_height(child_width, child_height);
+  //std::cout << "debug: " << G_STRFUNC << ": child width=" << child_width << std::endl;
+
+  const double x2 = x1 + child_width;
+  const double y2 = y1 + child_height;
+
+  Glib::RefPtr<Goocanvas::Item> item = CanvasItemMovable::cast_to_item(m_child);
+
+  set_edge_points(m_outline_top, x1, y1, x2, y1);
+  set_edge_points(m_outline_bottom, x1, y2, x2, y2);
+  set_edge_points(m_outline_left, x1, y1, x1, y2);
+  set_edge_points(m_outline_right, x2, y1, x2, y2);
+
+  /*
+  //Make sure that the bounds rect is below the item,
+  //and the manipulators are above the item (and above the rect):
+  if(item)
+  {
+    m_group_edge_manipulators->raise(item);
+    m_group_corner_manipulators->raise(item);
+    m_rect->lower(item);
+  }
+  else
+  {
+    m_group_edge_manipulators->raise(m_rect);
+    m_group_corner_manipulators->raise(m_rect);
+  }
+  */
 }
 
 void CanvasGroupResizable::set_child(const Glib::RefPtr<CanvasItemMovable>& child)
@@ -310,14 +410,17 @@ void CanvasGroupResizable::set_child(const Glib::RefPtr<CanvasItemMovable>& chil
 
   create_manipulators(); //Potentially changing the type of manipulators used, if the item is of a different type.
 
+  create_outline_group();
+
   //Set the child's position to match this parent resizable's position, if any was set:
   //(Note that the resizable should have its position set to that of the child, 
   //if that is the position that is wanted. 
   set_xy(x, y);
   set_width_height(width, height);
 
-  position_manipulators();
+  position_extras();
   set_manipulators_visibility(Goocanvas::ITEM_INVISIBLE);
+  set_outline_visible(false);
 }
 
 Glib::RefPtr<CanvasItemMovable> CanvasGroupResizable::get_child()
@@ -331,7 +434,7 @@ Glib::RefPtr<const CanvasItemMovable> CanvasGroupResizable::get_child() const
   return m_child;
 }
 
-void CanvasGroupResizable::manipulator_connect_signals(const Glib::RefPtr<Goocanvas::Item> manipulator, Manipulators manipulator_id)
+void CanvasGroupResizable::manipulator_connect_signals(const Glib::RefPtr<Goocanvas::Item>& manipulator, Manipulators manipulator_id)
 {
   //Respond when the corner rectangles move (they implement their own dragging):
 
@@ -416,7 +519,7 @@ Glib::RefPtr<CanvasItemMovable> CanvasGroupResizable::get_manipulator(Manipulato
   }
 }
 
-void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_id)
+void CanvasGroupResizable::on_manipulator_corner_moved(const Glib::RefPtr<CanvasItemMovable>& /* item */, double /* x_offset */, double /* y_offset */, Manipulators manipulator_id)
 {
   //Make sure that the manipulator is still visibile.
   //(if the user moves too fast then we get a leave-notify-event on the manipulator, rect, or item):
@@ -440,24 +543,13 @@ void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_
   get_width_height(child_width, child_height);
 
   switch(manipulator_id)
-  {
-#ifndef GLIBMM_PROPERTIES_ENABLED
-    // The compiler probably already does exactly this...
-    int x, y;
-    manipulator->get_property("x", x);
-    manipulator->get_property("y", y);
-#endif       
+  {     
     case(MANIPULATOR_CORNER_TOP_LEFT):
     {
       const double new_x = std::min(manipulator_x, child_x + child_width);
       const double new_y = std::min(manipulator_y, child_y + child_height);
-#ifdef GLIBMM_PROPERTIES_ENABLED      
       const double new_height = std::max(child_y + child_height - manipulator->property_y(), 0.0);
       const double new_width = std::max(child_x + child_width - manipulator->property_x(), 0.0);
-#else      
-      const double new_height = std::max(child_y + child_height - y, 0.0);
-      const double new_width = std::max(child_x + child_width - x, 0.0);
-#endif
       set_xy(new_x, new_y);
       set_width_height(new_width, new_height);
 
@@ -466,13 +558,8 @@ void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_
     case(MANIPULATOR_CORNER_TOP_RIGHT):
     {
       const double new_y = std::min(manipulator_y, child_y + child_height);
-#ifdef GLIBMM_PROPERTIES_ENABLED
       const double new_height = std::max(child_y + child_height - manipulator->property_y(), 0.0);
-      const double new_width = std::max(manipulator->property_x() + manipulator_corner_size - child_x, 0.0);
-#else      
-      const double new_height = std::max(child_y + child_height - y, 0.0);
-      const double new_width = std::max(x + manipulator_corner_size - child_x, 0.0);
-#endif
+      const double new_width = std::max(manipulator->property_x() + MANIPULATOR_CORNER_SIZE - child_x, 0.0);
 
       set_xy(child_x, new_y);
       set_width_height(new_width, new_height);
@@ -482,13 +569,8 @@ void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_
     case(MANIPULATOR_CORNER_BOTTOM_LEFT):
     {
       const double new_x = std::min(manipulator_x, child_x + child_width);
-#ifdef GLIBMM_PROPERTIES_ENABLED
-      const double new_height = std::max(manipulator->property_y() + manipulator_corner_size - child_y, 0.0);
+      const double new_height = std::max(manipulator->property_y() + MANIPULATOR_CORNER_SIZE - child_y, 0.0);
       const double new_width = std::max(child_x + child_width - manipulator->property_x(), 0.0);
-#else
-      const double new_height = std::max(y + manipulator_corner_size - child_y, 0.0);
-      const double new_width = std::max(child_x + child_width - x, 0.0);
-#endif
       set_xy(new_x, child_y);
       set_width_height(new_width, new_height);
 
@@ -496,13 +578,8 @@ void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_
     }
     case(MANIPULATOR_CORNER_BOTTOM_RIGHT):
     {
-#ifdef GLIBMM_PROPERTIES_ENABLED    
-      const double new_height = std::max(manipulator->property_y() + manipulator_corner_size - child_y, 0.0);
-      const double new_width = std::max(manipulator->property_x() + manipulator_corner_size - child_x, 0.0);
-#else
-      const double new_height = std::max(y + manipulator_corner_size - child_y, 0.0);
-      const double new_width = std::max(x + manipulator_corner_size - child_x, 0.0);
-#endif
+      const double new_height = std::max(manipulator->property_y() + MANIPULATOR_CORNER_SIZE - child_y, 0.0);
+      const double new_width = std::max(manipulator->property_x() + MANIPULATOR_CORNER_SIZE - child_x, 0.0);
       set_width_height(new_width, new_height);
 
       break;
@@ -511,11 +588,11 @@ void CanvasGroupResizable::on_manipulator_corner_moved(Manipulators manipulator_
       break;
   }
 
-  position_manipulators();
+  position_extras();
   m_signal_resized.emit();
 }
 
-void CanvasGroupResizable::on_manipulator_line_end_moved(Manipulators manipulator_id)
+void CanvasGroupResizable::on_manipulator_line_end_moved(const Glib::RefPtr<CanvasItemMovable>& /* item */, double /* x_offset */, double /* y_offset */, Manipulators manipulator_id)
 {
   //Make sure that the manipulator is still visibile.
   //(if the user moves too fast then we get a leave-notify-event on the manipulator, rect, or item):
@@ -538,26 +615,17 @@ void CanvasGroupResizable::on_manipulator_line_end_moved(Manipulators manipulato
   double manipulator_y = 0;
   manipulator->get_xy(manipulator_x, manipulator_y);
 
-#ifdef GLIBMM_PROPERTIES_ENABLED
   Goocanvas::Points points = line->property_points();
-#else
-  Goocanvas::Points points;
-  line->get_property("points", points);
-#endif
   
   if(points.get_num_points() < 2)
     return;
 
   const int point_index = (manipulator_id == MANIPULATOR_START) ? 0 : 1;
-  const double half_size = manipulator_corner_size / 2;
+  const double half_size = MANIPULATOR_CORNER_SIZE / 2;
   points.set_coordinate(point_index, manipulator_x + half_size, manipulator_y + half_size);
-#ifdef GLIBMM_PROPERTIES_ENABLED  
   line->property_points() = points; //TODO: Add a way to do this without getting and setting the points property.
-#else  
-  line->set_property("points", points); //TODO: Add a way to do this without getting and setting the points property.
-#endif
 
-  position_manipulators();
+  position_extras();
 }
 
 bool CanvasGroupResizable::on_manipulator_enter_notify_event(const Glib::RefPtr<Goocanvas::Item>& /* target */, GdkEventCrossing* /* event */)
@@ -574,7 +642,7 @@ bool CanvasGroupResizable::on_manipulator_leave_notify_event(const Glib::RefPtr<
   return false;
 }
 
-void CanvasGroupResizable::on_manipulator_edge_moved(Manipulators manipulator_id)
+void CanvasGroupResizable::on_manipulator_edge_moved(const Glib::RefPtr<CanvasItemMovable>& /* item */, double /* x_offset */, double /* y_offset */, Manipulators manipulator_id)
 {
   //Make sure that the manipulator is still visibile.
   //(if the user moves too fast then we get a leave-notify-event on the manipulator, rect, or item):
@@ -583,14 +651,9 @@ void CanvasGroupResizable::on_manipulator_edge_moved(Manipulators manipulator_id
   Glib::RefPtr<CanvasItemMovable> manipulator_base = get_manipulator(manipulator_id);
   Glib::RefPtr<CanvasLineMovable> manipulator = Glib::RefPtr<CanvasLineMovable>::cast_dynamic(manipulator_base);
   
-  //std::cout << "CanvasGroupResizable::on_manipulator_edge_moved(): manipulator=" << manipulator_id << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": manipulator=" << manipulator_id << std::endl;
 
-#ifdef GLIBMM_PROPERTIES_ENABLED
   Goocanvas::Points points = manipulator->property_points();
-#else  
-  Goocanvas::Points points;
-  manipulator->get_property("points", points);
-#endif
   double x1 = 0;
   double y1 = 0;
   points.get_coordinate(0, x1, y1);
@@ -648,7 +711,7 @@ void CanvasGroupResizable::on_manipulator_edge_moved(Manipulators manipulator_id
       break;
   }
 
-  position_manipulators();
+  position_extras();
   
   m_signal_resized.emit();
 }
@@ -665,7 +728,7 @@ bool CanvasGroupResizable::on_child_motion_notify_event(const Glib::RefPtr<Gooca
 
   const bool result = CanvasItemMovable::on_motion_notify_event(target, event);
   
-  position_manipulators();
+  position_extras();
 
   return result;
 }
@@ -696,15 +759,31 @@ bool CanvasGroupResizable::on_manipulator_motion_notify_event(const Glib::RefPtr
 
 void CanvasGroupResizable::set_manipulators_visibility(Goocanvas::ItemVisibility visibility)
 {
-  if(!m_group_manipulators)
+  if(!m_group_edge_manipulators || !m_group_corner_manipulators)
     return;
 
+  //Make sure that edges stays visible if the item is selected,
+  //because that is how we show selection:
+  Goocanvas::ItemVisibility edge_visibility = visibility;
+  if(get_selected())
+    edge_visibility = Goocanvas::ITEM_VISIBLE;
+
   //For testing: visibility = Goocanvas::ITEM_VISIBLE;
-#ifdef GLIBMM_PROPERTIES_ENABLED
-  m_group_manipulators->property_visibility() = visibility;
-#else  
-  m_group_manipulators->set_property("visibility", visibility);
-#endif
+  m_group_edge_manipulators->property_visibility() = edge_visibility;
+  m_group_corner_manipulators->property_visibility() = visibility;
+
+  //Also show grid lines in the portal table,
+  //though these are not actually manipulatable.
+  Glib::RefPtr<CanvasTableMovable> table = 
+    Glib::RefPtr<CanvasTableMovable>::cast_dynamic(get_child());
+  if(table)
+  {
+    if(visibility == Goocanvas::ITEM_VISIBLE)
+      table->set_lines_visibility();
+    else
+      table->set_lines_visibility(false);
+  }
+  
 }
 
 bool CanvasGroupResizable::on_rect_enter_notify_event(const Glib::RefPtr<Goocanvas::Item>& /* target */, GdkEventCrossing* /* event */)
@@ -754,34 +833,20 @@ bool CanvasGroupResizable::on_resizer_leave_notify_event(const Glib::RefPtr<Gooc
 Glib::RefPtr<CanvasRectMovable> CanvasGroupResizable::create_corner_manipulator()
 {
   Glib::RefPtr<CanvasRectMovable> result = CanvasRectMovable::create();
-#ifdef GLIBMM_PROPERTIES_ENABLED  
-  result->property_fill_color() = manipulator_corner_fill_color; //This makes the whole area clickable, not just the outline stroke:
-  result->property_line_width() = manipulator_stroke_width;
-  result->property_stroke_color() = manipulator_stroke_color;
+  result->property_fill_color() = MANIPULATOR_CORNER_FILL_COLOR; //This makes the whole area clickable, not just the outline stroke:
+  result->property_line_width() = MANIPULATOR_STROKE_WIDTH;
+  result->property_stroke_color() = MANIPULATOR_STROKE_COLOR;
 
-  result->property_height() = manipulator_corner_size;
-  result->property_width() = manipulator_corner_size;
-#else
-  result->set_property("fill-color", manipulator_corner_fill_color); //This makes the whole area clickable, not just the outline stroke:
-  result->set_property("line-width", manipulator_stroke_width);
-  result->set_property("stroke_color", manipulator_stroke_color);
-
-  result->set_property("height", manipulator_corner_size);
-  result->set_property("width", manipulator_corner_size);
-#endif
+  result->property_height() = MANIPULATOR_CORNER_SIZE;
+  result->property_width() = MANIPULATOR_CORNER_SIZE;
   return result;
 }
 
 Glib::RefPtr<CanvasLineMovable> CanvasGroupResizable::create_edge_manipulator()
 {
   Glib::RefPtr<Glom::CanvasLineMovable> line = Glom::CanvasLineMovable::create();
-#ifdef GLIBMM_PROPERTIES_ENABLED  
-  line->property_line_width() = manipulator_stroke_width;
-  line->property_stroke_color() = manipulator_stroke_color;
-#else
-  line->set_property("line-width", manipulator_stroke_width);
-  line->set_property("stroke-color", manipulator_stroke_color);
-#endif
+  line->property_line_width() = MANIPULATOR_STROKE_WIDTH;
+  line->property_stroke_color() = MANIPULATOR_STROKE_COLOR;
   return line;
 }
 
@@ -789,11 +854,7 @@ void CanvasGroupResizable::set_edge_points(const Glib::RefPtr<Glom::CanvasLineMo
 {
   double points_coordinates[] = {x1, y1, x2, y2};
   Goocanvas::Points points(2, points_coordinates);
-#ifdef GLIBMM_PROPERTIES_ENABLED  
   line->property_points() = points;
-#else  
-  line->set_property("points", points);
-#endif
 }
 
 void CanvasGroupResizable::get_xy(double& x, double& y) const
@@ -809,7 +870,7 @@ void CanvasGroupResizable::get_xy(double& x, double& y) const
 
 void CanvasGroupResizable::set_xy(double x, double y)
 {
-  //std::cout << "CanvasGroupResizable::set_xy(): " << x << ", " << y << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": " << x << ", " << y << std::endl;
   if(m_child)
     m_child->set_xy(x, y);
   
@@ -817,7 +878,7 @@ void CanvasGroupResizable::set_xy(double x, double y)
   m_x = x;
   m_y = y;
 
-  position_manipulators();
+  position_extras();
 }
 
 void CanvasGroupResizable::get_width_height(double& width, double& height) const
@@ -829,6 +890,15 @@ void CanvasGroupResizable::get_width_height(double& width, double& height) const
     width = m_width;
     height = m_height;
   }
+
+  //GooCanvasGroup allows height and width to be -1 to mean the "use the default",
+  //but other GooCanvas* items reject that as out of range,
+  //so prevent us from using it:
+  if(width == -1)
+    width = 100; //Arbitrary default.
+
+  if(height == -1)
+    height = 100; //Arbitrary default.
 }
 
 void CanvasGroupResizable::set_width_height(double width, double height)
@@ -840,7 +910,7 @@ void CanvasGroupResizable::set_width_height(double width, double height)
   m_width = width;
   m_height = height;
 
-  position_manipulators();
+  position_extras();
 }
 
 void CanvasGroupResizable::snap_position(double& x, double& y) const
@@ -934,5 +1004,52 @@ CanvasGroupResizable::type_signal_resized CanvasGroupResizable::signal_resized()
   return m_signal_resized;
 }
 
+void CanvasGroupResizable::set_grid(const Glib::RefPtr<const CanvasGroupGrid>& grid)
+{
+  //Call the base class:
+  CanvasItemMovable::set_grid(grid);
+
+  //Apply the grid to all the manipulators:
+  if(!m_group_edge_manipulators || !m_group_corner_manipulators)
+    return;
+
+  int count = m_group_edge_manipulators->get_n_children();
+  for(int i = 0; i < count; ++i)
+  {
+    Glib::RefPtr<Goocanvas::Item> child = m_group_edge_manipulators->get_child(i);
+    Glib::RefPtr<CanvasItemMovable> movable = CanvasItemMovable::cast_to_movable(child);
+    if(movable)
+    {
+      movable->set_grid(grid);
+    }
+  }
+
+  count = m_group_corner_manipulators->get_n_children();
+  for(int i = 0; i < count; ++i)
+  {
+    Glib::RefPtr<Goocanvas::Item> child = m_group_corner_manipulators->get_child(i);
+    Glib::RefPtr<CanvasItemMovable> movable = CanvasItemMovable::cast_to_movable(child);
+    if(movable)
+    {
+      movable->set_grid(grid);
+    }
+  }
+}
+
+void CanvasGroupResizable::show_selected()
+{
+  if(!m_group_edge_manipulators)
+    return;
+
+  Goocanvas::ItemVisibility edge_visibility = Goocanvas::ITEM_INVISIBLE;
+  if(get_selected())
+    edge_visibility = Goocanvas::ITEM_VISIBLE;
+
+  //This is also set the same way if set_manipulators_visibility(),
+  //in case that is called at some other time.
+  m_group_edge_manipulators->property_visibility() = edge_visibility;
+}
+
+
 } //namespace Glom
 
