@@ -35,8 +35,8 @@ CanvasLineMovable::CanvasLineMovable()
   signal_button_press_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_button_press_event));
   signal_button_release_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_button_release_event));
 
-  signal_enter_notify_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_enter_notify_event));
-  signal_leave_notify_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_leave_notify_event));
+  signal_enter_notify_event().connect(sigc::mem_fun(*this, &CanvasLineMovable::on_enter_notify_event));
+  signal_leave_notify_event().connect(sigc::mem_fun(*this, &CanvasLineMovable::on_leave_notify_event));
 }
 
 CanvasLineMovable::~CanvasLineMovable()
@@ -50,50 +50,30 @@ Glib::RefPtr<CanvasLineMovable> CanvasLineMovable::create()
 
 void CanvasLineMovable::get_xy(double& x, double& y) const
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   x = property_x();
   y = property_y();
-#else
-  get_property("x", x);
-  get_property("y", y);
-#endif
 }
 
 void CanvasLineMovable::set_xy(double x, double y)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_x() = x;
   property_y() = y;
-#else
-  set_property("x", x);
-  set_property("y", y);
-#endif
 }
 
 void CanvasLineMovable::get_width_height(double& width, double& height) const
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   width = property_width();
   height = property_height();
-#else
-  get_property("width", width);
-  get_property("height", height);
-#endif
 
-  //std::cout << "CanvasLineMovable::get_width_height(): width=" << width << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": width=" << width << std::endl;
 }
 
 void CanvasLineMovable::set_width_height(double width, double height)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_width() = width;
   property_height() = height;
-#else
-  set_property("width", width);
-  set_property("height", height);
-#endif
 
-  //std::cout << "CanvasLineMovable::set_width_height(): end x=" << x1+width << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": end x=" << x1+width << std::endl;
 }
 
 Goocanvas::Canvas* CanvasLineMovable::get_parent_canvas_widget()
@@ -101,5 +81,33 @@ Goocanvas::Canvas* CanvasLineMovable::get_parent_canvas_widget()
   return get_canvas();
 }
 
+void CanvasLineMovable::set_hover_color(const Glib::ustring& color)
+{
+  m_hover_color = color;
+}
+
+bool CanvasLineMovable::on_enter_notify_event(const Glib::RefPtr<Item>& target, GdkEventCrossing* event)
+{
+  if(!m_hover_color.empty())
+  {
+    m_stroke_color = property_stroke_color_rgba();
+    property_stroke_color() = m_hover_color;
+  }
+
+  CanvasItemMovable::on_enter_notify_event(target, event);
+  return Goocanvas::Polyline::on_enter_notify_event(target, event);
+}
+
+bool CanvasLineMovable::on_leave_notify_event(const Glib::RefPtr<Item>& target, GdkEventCrossing* event)
+{ 
+  if(!m_hover_color.empty())
+    property_stroke_color_rgba() = m_stroke_color;
+
+  CanvasItemMovable::on_leave_notify_event(target, event);
+  return Goocanvas::Polyline::on_leave_notify_event(target, event);
+}
+
+
+
 } //namespace Glom
 
