@@ -22,6 +22,7 @@
 
 #include "layoutwidgetutils.h"
 #include <glibmm/i18n.h>
+#include <gtkmm.h>
 #include <iostream>
 
 namespace Glom
@@ -117,7 +118,7 @@ void LayoutWidgetUtils::on_menu_delete_activate()
 void LayoutWidgetUtils::on_menu_properties_activate()
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << "LayoutWidgetUtils::on_menu_properties_activate(): Not imlemented. Derived classes should override this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not imlemented. Derived classes should override this." << std::endl;
 }
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
